# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Qbee(KaitaiStruct):
    """:field wod_time: beacon_data.wod.wod_time
    :field wod_mode: beacon_data.wod.wod_mode
    :field wod_voltage_battery: beacon_data.wod.wod_voltage_battery
    :field wod_current_battery: beacon_data.wod.wod_current_battery
    :field wod_current_3v3: beacon_data.wod.wod_current_3v3
    :field wod_current_5v: beacon_data.wod.wod_current_5v
    :field wod_temperature_comms: beacon_data.wod.wod_temperature_comms
    :field wod_temperature_eps: beacon_data.wod.wod_temperature_eps
    :field wod_temperature_battery: beacon_data.wod.wod_temperature_battery
    :field pwr_info_adcs: beacon_data.power_info.pwr_info_adcs
    :field pwr_info_fipex: beacon_data.power_info.pwr_info_fipex
    :field pwr_info_gps: beacon_data.power_info.pwr_info_gps
    :field pwr_info_ocobc: beacon_data.power_info.pwr_info_ocobc
    :field service_enabled_adcs: beacon_data.service_enabled.service_enabled_adcs
    :field service_enabled_fipex: beacon_data.service_enabled.service_enabled_fipex
    :field service_enabled_ocobc: beacon_data.service_enabled.service_enabled_ocobc
    :field service_running_adcs: beacon_data.service_running.service_running_adcs
    :field service_running_fipex: beacon_data.service_running.service_running_fipex
    :field service_running_ocobc: beacon_data.service_running.service_running_ocobc
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax_header = self._root.AxHeader(self._io, self, self._root)
        self.csp_header = self._io.read_bytes(4)
        self.beacon_data = self._root.BeaconData(self._io, self, self._root)
        self.rs_parity = self._io.read_bytes(32)

    class ServiceEnabled(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.service_enabled_adcs = self._io.read_bits_int(1) != 0
            self.service_enabled_fipex = self._io.read_bits_int(1) != 0
            self.service_enabled_ocobc = self._io.read_bits_int(1) != 0
            self.service_enabled_reserved = self._io.read_bits_int(5)


    class AxHeader(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.destination = (self._io.read_bytes(6)).decode(u"ASCII")
            self.destination_ssid = self._io.read_u1()
            self.source = (self._io.read_bytes(6)).decode(u"ASCII")
            self.source_ssid = self._io.read_u1()
            self.control = self._io.read_u1()
            self.pid = self._io.read_u1()


    class BeaconData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.wod = self._root.Wod(self._io, self, self._root)
            self.power_info = self._root.PowerInfo(self._io, self, self._root)
            self.service_enabled = self._root.ServiceEnabled(self._io, self, self._root)
            self.service_running = self._root.ServiceRunning(self._io, self, self._root)
            self.reserved = self._io.read_bytes(14)


    class ServiceRunning(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.service_running_adcs = self._io.read_bits_int(1) != 0
            self.service_running_fipex = self._io.read_bits_int(1) != 0
            self.service_running_ocobc = self._io.read_bits_int(1) != 0
            self.service_running_reserved = self._io.read_bits_int(5)


    class PowerInfo(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pwr_info_adcs = self._io.read_bits_int(1) != 0
            self.pwr_info_fipex = self._io.read_bits_int(1) != 0
            self.pwr_info_gps = self._io.read_bits_int(1) != 0
            self.pwr_info_ocobc = self._io.read_bits_int(1) != 0
            self.pwr_info_reserved = self._io.read_bits_int(4)


    class Wod(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.wod_time = self._io.read_u4le()
            self.wod_mode = self._io.read_u1()
            self.wod_voltage_battery = self._io.read_u1()
            self.wod_current_battery = self._io.read_u1()
            self.wod_current_3v3 = self._io.read_u1()
            self.wod_current_5v = self._io.read_u1()
            self.wod_temperature_comms = self._io.read_u1()
            self.wod_temperature_eps = self._io.read_u1()
            self.wod_temperature_battery = self._io.read_u1()






"""
SatNOGS Decoder subpackage initialization
"""
from __future__ import absolute_import, division, print_function

__all__ = [
    'Ax25frames',
    'Ax25monitor',
    'Bugsat1',
    'Cas4',
    'Cubebel1',
    'Cubesatsim',
    'Csim',
    'Elfin',
    'Fox',
    'Irvine',
    'Minxss',
    'Origamisat1',
    'Pwsat2',
    'Qbee',
    'Siriussat',
    'Skcube',
    'Strand',
    'Us6',
    'Uwe4',
]

import re
import functools

from .ax25frames import Ax25frames
from .ax25monitor import Ax25monitor
from .bugsat1 import Bugsat1
from .cas4 import Cas4
from .cubebel1 import Cubebel1
from .cubesatsim import Cubesatsim
from .csim import Csim
from .elfin import Elfin
from .fox import Fox
from .irvine import Irvine
from .minxss import Minxss
from .origamisat1 import Origamisat1
from .pwsat2 import Pwsat2
from .qbee import Qbee
from .siriussat import Siriussat
from .skcube import Skcube
from .strand import Strand
from .us6 import Us6
from .uwe4 import Uwe4

FIELD_REGEX = re.compile(
    r':field (?P<field>[\*\w]+): (?P<attribute>.*?)'
    r'(?:(?=:field)|\Z|\n)', re.S)


def get_fields(struct, empty=False):
    '''
    Get fields defined in docstring
    '''
    fields = {}

    try:
        doc_fields = FIELD_REGEX.findall(struct.__doc__)
    except TypeError:
        return fields

    for key, value in doc_fields:
        try:
            fields[key] = functools.reduce(getattr, value.split('.'), struct)
        except AttributeError:
            if empty:
                fields[key] = None

    return fields



# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Skcube(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field packet_type: ax25_frame.payload.ax25_info.packet_type
    :field adcs_mode: ax25_frame.payload.ax25_info.telemetry.adcs_mode
    :field bd_k: ax25_frame.payload.ax25_info.telemetry.bd_k
    :field max_pwm_coil_x: ax25_frame.payload.ax25_info.telemetry.max_pwm_coil_x
    :field max_pwm_coil_y: ax25_frame.payload.ax25_info.telemetry.max_pwm_coil_y
    :field max_pwm_coil_z: ax25_frame.payload.ax25_info.telemetry.max_pwm_coil_z
    :field sun_x_p_x: ax25_frame.payload.ax25_info.telemetry.sun_x_p_x
    :field sun_x_p_y: ax25_frame.payload.ax25_info.telemetry.sun_x_p_y
    :field sun_x_p_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_x_p_irradiation
    :field sun_x_m_x: ax25_frame.payload.ax25_info.telemetry.sun_x_m_x
    :field sun_x_m_y: ax25_frame.payload.ax25_info.telemetry.sun_x_m_y
    :field sun_x_m_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_x_m_irradiation
    :field sun_y_p_x: ax25_frame.payload.ax25_info.telemetry.sun_y_p_x
    :field sun_y_p_y: ax25_frame.payload.ax25_info.telemetry.sun_y_p_y
    :field sun_y_p_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_y_p_irradiation
    :field sun_y_m_x: ax25_frame.payload.ax25_info.telemetry.sun_y_m_x
    :field sun_y_m_y: ax25_frame.payload.ax25_info.telemetry.sun_y_m_y
    :field sun_y_m_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_y_m_irradiation
    :field sun_z_p_x: ax25_frame.payload.ax25_info.telemetry.sun_z_p_x
    :field sun_z_p_y: ax25_frame.payload.ax25_info.telemetry.sun_z_p_y
    :field sun_z_p_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_z_p_irradiation
    :field sun_z_m_x: ax25_frame.payload.ax25_info.telemetry.sun_z_m_x
    :field sun_z_m_y: ax25_frame.payload.ax25_info.telemetry.sun_z_m_y
    :field sun_z_m_irradiation: ax25_frame.payload.ax25_info.telemetry.sun_z_m_irradiation
    :field gyroscopex: ax25_frame.payload.ax25_info.telemetry.gyroscopex
    :field gyroscopey: ax25_frame.payload.ax25_info.telemetry.gyroscopey
    :field gyroscopez: ax25_frame.payload.ax25_info.telemetry.gyroscopez
    :field gyroscope_temp: ax25_frame.payload.ax25_info.telemetry.gyroscope_temp
    :field magnetometer_1_x: ax25_frame.payload.ax25_info.telemetry.magnetometer_1_x
    :field magnetometer_1_y: ax25_frame.payload.ax25_info.telemetry.magnetometer_1_y
    :field magnetometer_1_z: ax25_frame.payload.ax25_info.telemetry.magnetometer_1_z
    :field magnetometer_1_temp: ax25_frame.payload.ax25_info.telemetry.magnetometer_1_temp
    :field magnetometer_2_x: ax25_frame.payload.ax25_info.telemetry.magnetometer_2_x
    :field magnetometer_2_y: ax25_frame.payload.ax25_info.telemetry.magnetometer_2_y
    :field magnetometer_2_z: ax25_frame.payload.ax25_info.telemetry.magnetometer_2_z
    :field magnetometer_2_temp: ax25_frame.payload.ax25_info.telemetry.magnetometer_2_temp
    :field accelerometer_x: ax25_frame.payload.ax25_info.telemetry.accelerometer_x
    :field accelerometer_y: ax25_frame.payload.ax25_info.telemetry.accelerometer_y
    :field accelerometer_z: ax25_frame.payload.ax25_info.telemetry.accelerometer_z
    :field accel_temp: ax25_frame.payload.ax25_info.telemetry.accel_temp
    :field earth_sensor_x_m: ax25_frame.payload.ax25_info.telemetry.earth_sensor_x_m
    :field earth_sensor_x_p: ax25_frame.payload.ax25_info.telemetry.earth_sensor_x_p
    :field earth_sensor_y_m: ax25_frame.payload.ax25_info.telemetry.earth_sensor_y_m
    :field earth_sensor_y_p: ax25_frame.payload.ax25_info.telemetry.earth_sensor_y_p
    :field timestamp: ax25_frame.payload.ax25_info.telemetry.timestamp
    :field fwversion: ax25_frame.payload.ax25_info.telemetry.fwversion
    :field activecom: ax25_frame.payload.ax25_info.telemetry.activecom
    :field digipeatermode: ax25_frame.payload.ax25_info.telemetry.digipeatermode
    :field noofreboots: ax25_frame.payload.ax25_info.telemetry.noofreboots
    :field outputreflpower: ax25_frame.payload.ax25_info.telemetry.outputreflpower
    :field outputforwardpower: ax25_frame.payload.ax25_info.telemetry.outputforwardpower
    :field outputreflpowercw: ax25_frame.payload.ax25_info.telemetry.outputreflpowercw
    :field outputforwardpowercw: ax25_frame.payload.ax25_info.telemetry.outputforwardpowercw
    :field rssi: ax25_frame.payload.ax25_info.telemetry.rssi
    :field rssinoise: ax25_frame.payload.ax25_info.telemetry.rssinoise
    :field mcutemperature: ax25_frame.payload.ax25_info.telemetry.mcutemperature
    :field patemperature: ax25_frame.payload.ax25_info.telemetry.patemperature
    :field cwbeaconsent: ax25_frame.payload.ax25_info.telemetry.cwbeaconsent
    :field packetsent: ax25_frame.payload.ax25_info.telemetry.packetsent
    :field correctpacketsreceived: ax25_frame.payload.ax25_info.telemetry.correctpacketsreceived
    :field brokenpacketsreceived: ax25_frame.payload.ax25_info.telemetry.brokenpacketsreceived
    :field comprotocolerror: ax25_frame.payload.ax25_info.telemetry.comprotocolerror
    :field gsprotocolerror: ax25_frame.payload.ax25_info.telemetry.gsprotocolerror
    :field txdisablestatus: ax25_frame.payload.ax25_info.telemetry.txdisablestatus
    :field orbittime: ax25_frame.payload.ax25_info.telemetry.orbittime
    :field timeslotstart: ax25_frame.payload.ax25_info.telemetry.timeslotstart
    :field timeslotend: ax25_frame.payload.ax25_info.telemetry.timeslotend
    :field fw_version: ax25_frame.payload.ax25_info.telemetry.fw_version
    :field number_of_reboots: ax25_frame.payload.ax25_info.telemetry.number_of_reboots
    :field jpeg_compression: ax25_frame.payload.ax25_info.telemetry.jpeg_compression
    :field jpeg_scale: ax25_frame.payload.ax25_info.telemetry.jpeg_scale
    :field mcu_temperature: ax25_frame.payload.ax25_info.telemetry.mcu_temperature
    :field vref_internal: ax25_frame.payload.ax25_info.telemetry.vref_internal
    :field packets_sent: ax25_frame.payload.ax25_info.telemetry.packets_sent
    :field cw_sent: ax25_frame.payload.ax25_info.telemetry.cw_sent
    :field flash_image_position: ax25_frame.payload.ax25_info.telemetry.flash_image_position
    :field tx_datarate: ax25_frame.payload.ax25_info.telemetry.tx_datarate
    :field fulluptime: ax25_frame.payload.ax25_info.telemetry.fulluptime
    :field uptime: ax25_frame.payload.ax25_info.telemetry.uptime
    :field active_procesor: ax25_frame.payload.ax25_info.telemetry.active_procesor
    :field countcomerrors: ax25_frame.payload.ax25_info.telemetry.countcomerrors
    :field countpsuerrors: ax25_frame.payload.ax25_info.telemetry.countpsuerrors
    :field solar_j_current: ax25_frame.payload.ax25_info.telemetry.solar_j_current
    :field solar_k_current: ax25_frame.payload.ax25_info.telemetry.solar_k_current
    :field solar_l_current: ax25_frame.payload.ax25_info.telemetry.solar_l_current
    :field solar_m_current: ax25_frame.payload.ax25_info.telemetry.solar_m_current
    :field solar_u_current: ax25_frame.payload.ax25_info.telemetry.solar_u_current
    :field solar_d_current: ax25_frame.payload.ax25_info.telemetry.solar_d_current
    :field solar_j_temp: ax25_frame.payload.ax25_info.telemetry.solar_j_temp
    :field solar_k_temp: ax25_frame.payload.ax25_info.telemetry.solar_k_temp
    :field solar_l_temp: ax25_frame.payload.ax25_info.telemetry.solar_l_temp
    :field solar_m_temp: ax25_frame.payload.ax25_info.telemetry.solar_m_temp
    :field solar_u_temp: ax25_frame.payload.ax25_info.telemetry.solar_u_temp
    :field solar_d_temp: ax25_frame.payload.ax25_info.telemetry.solar_d_temp
    :field battery_a_voltage: ax25_frame.payload.ax25_info.telemetry.battery_a_voltage
    :field battery_b_voltage: ax25_frame.payload.ax25_info.telemetry.battery_b_voltage
    :field battery_temp: ax25_frame.payload.ax25_info.telemetry.battery_temp
    :field battery_a_capacity: ax25_frame.payload.ax25_info.telemetry.battery_b_capacity
    :field bat_capacity: ax25_frame.payload.ax25_info.telemetry.bat_capacity
    :field battery_a_current: ax25_frame.payload.ax25_info.telemetry.battery_a_current
    :field battery_b_current: ax25_frame.payload.ax25_info.telemetry.battery_b_current
    :field battery_a_min_current: ax25_frame.payload.ax25_info.telemetry.battery_a_min_current
    :field battery_b_min_current: ax25_frame.payload.ax25_info.telemetry.battery_b_min_current
    :field battery_a_max_current: ax25_frame.payload.ax25_info.telemetry.battery_a_max_current
    :field battery_b_max_current: ax25_frame.payload.ax25_info.telemetry.battery_b_max_current
    :field battery_a_avg_current: ax25_frame.payload.ax25_info.telemetry.battery_a_avg_current
    :field battery_b_avg_current: ax25_frame.payload.ax25_info.telemetry.battery_b_avg_current
    :field chds_min_current: ax25_frame.payload.ax25_info.telemetry.chds_min_current
    :field chds_max_current: ax25_frame.payload.ax25_info.telemetry.chds_max_current
    :field chds_avg_current: ax25_frame.payload.ax25_info.telemetry.chds_avg_current
    :field chds_actual_current: ax25_frame.payload.ax25_info.telemetry.chds_actual_current
    :field cam_min_current: ax25_frame.payload.ax25_info.telemetry.cam_min_current
    :field cam_max_current: ax25_frame.payload.ax25_info.telemetry.cam_max_current
    :field cam_avg_current: ax25_frame.payload.ax25_info.telemetry.cam_avg_current
    :field cam_actual_current: ax25_frame.payload.ax25_info.telemetry.cam_actual_current
    :field exp_min_current: ax25_frame.payload.ax25_info.telemetry.exp_min_current
    :field exp_max_current: ax25_frame.payload.ax25_info.telemetry.exp_max_current
    :field exp_avg_current: ax25_frame.payload.ax25_info.telemetry.exp_avg_current
    :field exp_actual_current: ax25_frame.payload.ax25_info.telemetry.exp_actual_current
    :field adcs_min_current: ax25_frame.payload.ax25_info.telemetry.adcs_min_current
    :field adcs_max_current: ax25_frame.payload.ax25_info.telemetry.adcs_max_current
    :field adcs_avg_current: ax25_frame.payload.ax25_info.telemetry.adcs_avg_current
    :field adcs_actual_current: ax25_frame.payload.ax25_info.telemetry.adcs_actual_current
    :field sys_voltage_min: ax25_frame.payload.ax25_info.telemetry.sys_voltage_min
    :field sys_voltage_max: ax25_frame.payload.ax25_info.telemetry.sys_voltage_max
    :field sys_voltage_actual: ax25_frame.payload.ax25_info.telemetry.sys_voltage_actual
    :field nadprudy: ax25_frame.payload.ax25_info.telemetry.nadprudy
    :field stav_pripojenia: ax25_frame.payload.ax25_info.telemetry.stav_pripojenia
    :field ts_temp: ax25_frame.payload.ax25_info.telemetry.ts_temp
    :field countpacket: ax25_frame.payload.ax25_info.telemetry.countpacket
    :field psu_error: ax25_frame.payload.ax25_info.telemetry.psu_error
    :field psu_lasterror: ax25_frame.payload.ax25_info.telemetry.psu_lasterror
    :field com_error: ax25_frame.payload.ax25_info.telemetry.com_error
    :field com_lasterror: ax25_frame.payload.ax25_info.telemetry.com_lasterror
    :field cdhs_i_limit: ax25_frame.payload.ax25_info.telemetry.cdhs_i_limit
    :field com_i_limit: ax25_frame.payload.ax25_info.telemetry.com_i_limit
    :field cam_i_limit: ax25_frame.payload.ax25_info.telemetry.cam_i_limit
    :field adcs_i_limit: ax25_frame.payload.ax25_info.telemetry.adcs_i_limit
    :field exp_i_limit: ax25_frame.payload.ax25_info.telemetry.exp_i_limit
    :field cam_uv_limit: ax25_frame.payload.ax25_info.telemetry.cam_uv_limit
    :field adcs_uv_limit: ax25_frame.payload.ax25_info.telemetry.adcs_uv_limit
    :field bat1_vmax: ax25_frame.payload.ax25_info.telemetry.bat1_vmax
    :field bat1_vmin: ax25_frame.payload.ax25_info.telemetry.bat1_vmin
    :field bat2_vmax: ax25_frame.payload.ax25_info.telemetry.bat2_vmax
    :field bat2_vmin: ax25_frame.payload.ax25_info.telemetry.bat2_vmin
    :field endofdata: ax25_frame.payload.ax25_info.telemetry.endofdata
    :field active_adc_channel: ax25_frame.payload.ax25_info.telemetry.active_adc_channel
    :field fft_gain: ax25_frame.payload.ax25_info.telemetry.fft_gain
    :field low_frequency: ax25_frame.payload.ax25_info.telemetry.low_frequency
    :field high_frequency: ax25_frame.payload.ax25_info.telemetry.high_frequency
    :field max_hold_sec: ax25_frame.payload.ax25_info.telemetry.max_hold_sec
    :field slow_position: ax25_frame.payload.ax25_info.telemetry.slow_position
    :field postring_samples: ax25_frame.payload.ax25_info.telemetry.postring_samples
    :field psd: ax25_frame.payload.ax25_info.telemetry.psd
    :field psd_max: ax25_frame.payload.ax25_info.telemetry.psd_max
    :field psd_selected: ax25_frame.payload.ax25_info.telemetry.psd_selected
    :field psd_selected_max: ax25_frame.payload.ax25_info.telemetry.psd_selected_max
    :field peak_freq: ax25_frame.payload.ax25_info.telemetry.peak_freq
    :field peak_amp: ax25_frame.payload.ax25_info.telemetry.peak_amp
    :field psd_threshold: ax25_frame.payload.ax25_info.telemetry.psd_threshold
    :field psd_selected_events: ax25_frame.payload.ax25_info.telemetry.psd_selected_events
    :field events_position: ax25_frame.payload.ax25_info.telemetry.events_position
    :field event_time_1: ax25_frame.payload.ax25_info.telemetry.event_time_1
    :field event_time_2: ax25_frame.payload.ax25_info.telemetry.event_time_2
    :field event_time_3: ax25_frame.payload.ax25_info.telemetry.event_time_3
    :field event_time_4: ax25_frame.payload.ax25_info.telemetry.event_time_4
    :field event_time_5: ax25_frame.payload.ax25_info.telemetry.event_time_5
    :field event_time_6: ax25_frame.payload.ax25_info.telemetry.event_time_6
    :field event_time_7: ax25_frame.payload.ax25_info.telemetry.event_time_7
    :field event_time_8: ax25_frame.payload.ax25_info.telemetry.event_time_8
    :field event_time_9: ax25_frame.payload.ax25_info.telemetry.event_time_9
    :field event_time_10: ax25_frame.payload.ax25_info.telemetry.event_time_10
    :field message: ax25_frame.payload.ax25_info.telemetry.message
    
    .. seealso::
       Source - http://www.skcube.sk/wp-content/uploads/2016/06/skcube_data_structures.xlsx
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = self._root.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = self._root.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = self._root.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            _on = self.pid
            if _on == 240:
                self._raw_ax25_info = self._io.read_bytes_full()
                io = KaitaiStream(BytesIO(self._raw_ax25_info))
                self.ax25_info = self._root.SkcubeFrame(io, self, self._root)
            else:
                self.ax25_info = self._io.read_bytes_full()


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class SkcubeFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self.packet_type
            if _on == 4:
                self.telemetry = self._root.SkcubeFrame.Block4Cam(self._io, self, self._root)
            elif _on == 6:
                self.telemetry = self._root.SkcubeFrame.Block6Exp(self._io, self, self._root)
            elif _on == 3:
                self.telemetry = self._root.SkcubeFrame.Block3Com(self._io, self, self._root)
            elif _on == 5:
                self.telemetry = self._root.SkcubeFrame.Block5Pwr(self._io, self, self._root)
            elif _on == 2:
                self.telemetry = self._root.SkcubeFrame.Block2Adcs(self._io, self, self._root)
            else:
                self.telemetry = self._root.SkcubeFrame.BlockMessage(self._io, self, self._root)

        class Block5Pwr(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.packet_type_holder = self._io.read_u1()
                self.timestamp = self._io.read_u4le()
                self.fulluptime = self._io.read_u4le()
                self.uptime = self._io.read_u4le()
                self.active_procesor = self._io.read_u2le()
                self.fw_version = self._io.read_u2le()
                self.number_of_reboots = self._io.read_u2le()
                self.countcomerrors = self._io.read_u2le()
                self.countpsuerrors = self._io.read_u2le()
                self.solar_j_current = self._io.read_s2le()
                self.solar_k_current = self._io.read_s2le()
                self.solar_l_current = self._io.read_s2le()
                self.solar_m_current = self._io.read_s2le()
                self.solar_u_current = self._io.read_s2le()
                self.solar_d_current = self._io.read_s2le()
                self.solar_j_temp = self._io.read_s2le()
                self.solar_k_temp = self._io.read_s2le()
                self.solar_l_temp = self._io.read_s2le()
                self.solar_m_temp = self._io.read_s2le()
                self.solar_u_temp = self._io.read_s2le()
                self.solar_d_temp = self._io.read_s2le()
                self.battery_a_voltage = self._io.read_s2le()
                self.battery_b_voltage = self._io.read_s2le()
                self.battery_temp = self._io.read_s2le()
                self.battery_a_capacity = self._io.read_u2le()
                self.battery_b_capacity = self._io.read_u2le()
                self.bat_capacity = self._io.read_u2le()
                self.battery_a_current = self._io.read_s2le()
                self.battery_b_current = self._io.read_s2le()
                self.battery_a_min_current = self._io.read_s2le()
                self.battery_b_min_current = self._io.read_s2le()
                self.battery_a_max_current = self._io.read_s2le()
                self.battery_b_max_current = self._io.read_s2le()
                self.battery_a_avg_current = self._io.read_s2le()
                self.battery_b_avg_current = self._io.read_s2le()
                self.chds_min_current = self._io.read_s2le()
                self.chds_max_current = self._io.read_s2le()
                self.chds_avg_current = self._io.read_s2le()
                self.chds_actual_current = self._io.read_s2le()
                self.com_min_current = self._io.read_s2le()
                self.com_max_current = self._io.read_s2le()
                self.com_avg_current = self._io.read_s2le()
                self.com_actual_current = self._io.read_s2le()
                self.cam_min_current = self._io.read_s2le()
                self.cam_max_current = self._io.read_s2le()
                self.cam_avg_current = self._io.read_s2le()
                self.cam_actual_current = self._io.read_s2le()
                self.exp_min_current = self._io.read_s2le()
                self.exp_max_current = self._io.read_s2le()
                self.exp_avg_current = self._io.read_s2le()
                self.exp_actual_current = self._io.read_s2le()
                self.adcs_min_current = self._io.read_s2le()
                self.adcs_max_current = self._io.read_s2le()
                self.adcs_avg_current = self._io.read_s2le()
                self.adcs_actual_current = self._io.read_s2le()
                self.sys_voltage_min = self._io.read_u2le()
                self.sys_voltage_max = self._io.read_u2le()
                self.sys_voltage_actual = self._io.read_u2le()
                self.nadprudy = self._io.read_u2le()
                self.stav_pripojenia = self._io.read_u2le()
                self.ts_temp = self._io.read_s2le()
                self.countpacket = self._io.read_u4le()
                self.psu_error = self._io.read_u2le()
                self.psu_lasterror = self._io.read_u2le()
                self.com_error = self._io.read_u2le()
                self.com_lasterror = self._io.read_u2le()
                self.cdhs_i_limit = self._io.read_u1()
                self.com_i_limit = self._io.read_u1()
                self.cam_i_limit = self._io.read_u1()
                self.adcs_i_limit = self._io.read_u1()
                self.exp_i_limit = self._io.read_u1()
                self.cam_uv_limit = self._io.read_u1()
                self.exp_uv_limit = self._io.read_u1()
                self.adcs_uv_limit = self._io.read_u1()
                self.bat1_vmax = self._io.read_s2le()
                self.bat1_vmin = self._io.read_s2le()
                self.bat2_vmax = self._io.read_s2le()
                self.bat2_vmin = self._io.read_s2le()
                self.endofdata = self._io.read_u2le()


        class Block2Adcs(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.packet_type_holder = self._io.read_u1()
                self.adcs_mode = self._io.read_u1()
                self.bd_k = self._io.read_u1()
                self.max_pwm_coil_x = self._io.read_u1()
                self.max_pwm_coil_y = self._io.read_u1()
                self.max_pwm_coil_z = self._io.read_u1()
                self.sun_x_p_x = self._io.read_s2le()
                self.sun_x_p_y = self._io.read_s2le()
                self.sun_x_p_irradiation = self._io.read_u1()
                self.sun_x_m_x = self._io.read_s2le()
                self.sun_x_m_y = self._io.read_s2le()
                self.sun_x_m_irradiation = self._io.read_u1()
                self.sun_y_p_x = self._io.read_s2le()
                self.sun_y_p_y = self._io.read_s2le()
                self.sun_y_p_irradiation = self._io.read_u1()
                self.sun_y_m_x = self._io.read_s2le()
                self.sun_y_m_y = self._io.read_s2le()
                self.sun_y_m_irradiation = self._io.read_u1()
                self.sun_z_p_x = self._io.read_s2le()
                self.sun_z_p_y = self._io.read_s2le()
                self.sun_z_p_irradiation = self._io.read_u1()
                self.sun_z_m_x = self._io.read_s2le()
                self.sun_z_m_y = self._io.read_s2le()
                self.sun_z_m_irradiation = self._io.read_u1()
                self.gyroscope_x = self._io.read_u2le()
                self.gyroscope_y = self._io.read_u2le()
                self.gyroscope_z = self._io.read_u2le()
                self.gyroscope_temp = self._io.read_u2le()
                self.magnetometer_1_x = self._io.read_u2le()
                self.magnetometer_1_y = self._io.read_u2le()
                self.magnetometer_1_z = self._io.read_u2le()
                self.magnetometer_1_temp = self._io.read_u2le()
                self.magnetometer_2_x = self._io.read_u2le()
                self.magnetometer_2_y = self._io.read_u2le()
                self.magnetometer_2_z = self._io.read_u2le()
                self.magnetometer_2_temp = self._io.read_u2le()
                self.accelerometer_x = self._io.read_u2le()
                self.accelerometer_y = self._io.read_u2le()
                self.accelerometer_z = self._io.read_u2le()
                self.accel_temp = self._io.read_u2le()
                self.earth_sensor_x_p = self._io.read_u2le()
                self.earth_sensor_x_m = self._io.read_u2le()
                self.earth_sensor_y_p = self._io.read_u2le()
                self.earth_sensor_y_m = self._io.read_u2le()


        class Block3Com(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.packet_type_holder = self._io.read_u1()
                self.timestamp = self._io.read_u4le()
                self.fwversion = self._io.read_u2le()
                self.activecom = self._io.read_u1()
                self.digipeatermode = self._io.read_u1()
                self.noofreboots = self._io.read_u2le()
                self.outputreflpower = self._io.read_u2le()
                self.outputforwardpower = self._io.read_u2le()
                self.outputreflpowercw = self._io.read_u2le()
                self.outputforwardpowercw = self._io.read_u2le()
                self.rssi = self._io.read_u2le()
                self.rssinoise = self._io.read_u2le()
                self.mcutemperature = self._io.read_s1()
                self.patemperature = self._io.read_s1()
                self.cwbeaconsent = self._io.read_u2le()
                self.packetsent = self._io.read_u2le()
                self.correctpacketsreceived = self._io.read_u2le()
                self.brokenpacketsreceived = self._io.read_u2le()
                self.comprotocolerror = self._io.read_u2le()
                self.gsprotocolerror = self._io.read_u2le()
                self.txdisablestatus = self._io.read_u1()
                self.orbittime = self._io.read_u1()
                self.timeslotstart = self._io.read_u1()
                self.timeslotend = self._io.read_u1()


        class Block6Exp(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.packet_type_holder = self._io.read_u1()
                self.timestamp = self._io.read_u4le()
                self.fw_version = self._io.read_u2le()
                self.number_of_reboots = self._io.read_u2le()
                self.active_adc_channel = self._io.read_u1()
                self.fft_gain = self._io.read_u1()
                self.low_frequency = self._io.read_u1()
                self.high_frequency = self._io.read_u1()
                self.max_hold_sec = self._io.read_u2le()
                self.slow_position = self._io.read_u2le()
                self.postring_samples = self._io.read_u2le()
                self.psd = self._io.read_u2le()
                self.psd_max = self._io.read_u2le()
                self.psd_selected = self._io.read_u2le()
                self.psd_selected_max = self._io.read_u2le()
                self.peak_freq = self._io.read_u2le()
                self.peak_amp = self._io.read_u2le()
                self.psd_threshold = self._io.read_u2le()
                self.psd_selected_events = self._io.read_u2le()
                self.events_position = self._io.read_u1()
                self.event_time_1 = self._io.read_u4le()
                self.event_time_2 = self._io.read_u4le()
                self.event_time_3 = self._io.read_u4le()
                self.event_time_4 = self._io.read_u4le()
                self.event_time_5 = self._io.read_u4le()
                self.event_time_6 = self._io.read_u4le()
                self.event_time_7 = self._io.read_u4le()
                self.event_time_8 = self._io.read_u4le()
                self.event_time_9 = self._io.read_u4le()
                self.event_time_10 = self._io.read_u4le()


        class BlockMessage(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.message = (self._io.read_bytes_full()).decode(u"utf-8")


        class Block4Cam(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.packet_type_holder = self._io.read_u1()
                self.timestamp = self._io.read_u4le()
                self.fw_version = self._io.read_u2le()
                self.number_of_reboots = self._io.read_u2le()
                self.jpeg_compression = self._io.read_u1()
                self.jpeg_scale = self._io.read_u1()
                self.mcu_temperature = self._io.read_s1()
                self.vref_internal = self._io.read_u2le()
                self.packets_sent = self._io.read_u2le()
                self.cw_sent = self._io.read_u2le()
                self.flash_image_position = self._io.read_u1()
                self.tx_datarate = self._io.read_u1()


        @property
        def packet_type(self):
            if hasattr(self, '_m_packet_type'):
                return self._m_packet_type if hasattr(self, '_m_packet_type') else None

            _pos = self._io.pos()
            self._io.seek(0)
            self._m_packet_type = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_packet_type if hasattr(self, '_m_packet_type') else None


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            io = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = self._root.Callsign(io, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Origamisat1(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field rpt_callsign: ax25_frame.ax25_header.repeater.rpt_instance[0].rpt_callsign_raw.callsign_ror.callsign
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field last_exec_obc_id: ax25_frame.payload.ax25_info.hk_data.chunk.last_exec_obc_id
    :field obc_cmd_status: ax25_frame.payload.ax25_info.hk_data.chunk.obc_cmd_status
    :field data_obtained_time_year: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_year
    :field data_obtained_time_month: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_month
    :field data_obtained_time_day: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_day
    :field data_obtained_time_hour: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_hour
    :field data_obtained_time_minute: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_minute
    :field data_obtained_time_second: ax25_frame.payload.ax25_info.hk_data.chunk.data_obtained_time_second
    :field battery_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.battery_voltage
    :field battery_current: ax25_frame.payload.ax25_info.hk_data.chunk.battery_current
    :field bat_status: ax25_frame.payload.ax25_info.hk_data.chunk.bat_status
    :field eps_sw_status: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_status
    :field eps_bus_status: ax25_frame.payload.ax25_info.hk_data.chunk.eps_bus_status
    :field satellite_mode: ax25_frame.payload.ax25_info.hk_data.chunk.satellite_mode
    :field sap_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.sap_voltage
    :field sap_current: ax25_frame.payload.ax25_info.hk_data.chunk.sap_current
    :field sap_1_gen_pwr: ax25_frame.payload.ax25_info.hk_data.chunk.sap_1_gen_pwr
    :field sap_2_gen_pwr: ax25_frame.payload.ax25_info.hk_data.chunk.sap_2_gen_pwr
    :field sap_3_gen_pwr: ax25_frame.payload.ax25_info.hk_data.chunk.sap_3_gen_pwr
    :field sap_4_gen_pwr: ax25_frame.payload.ax25_info.hk_data.chunk.sap_4_gen_pwr
    :field sap_5_gen_pwr: ax25_frame.payload.ax25_info.hk_data.chunk.sap_5_gen_pwr
    :field sap_2_current: ax25_frame.payload.ax25_info.hk_data.chunk.sap_2_current
    :field sap_3_current: ax25_frame.payload.ax25_info.hk_data.chunk.sap_3_current
    :field sap_4_current: ax25_frame.payload.ax25_info.hk_data.chunk.sap_4_current
    :field sap_5_current: ax25_frame.payload.ax25_info.hk_data.chunk.sap_5_current
    :field eps_temp: ax25_frame.payload.ax25_info.hk_data.chunk.eps_temp
    :field obc_cmd_status: ax25_frame.payload.ax25_info.hk_data.chunk.
    :field obc_temp_0: ax25_frame.payload.ax25_info.hk_data.chunk.obc_temp_0
    :field obc_temp_1: ax25_frame.payload.ax25_info.hk_data.chunk.obc_temp_1
    :field amp_5g8hz_temp: ax25_frame.payload.ax25_info.hk_data.chunk.amp_5g8hz_temp
    :field rad_plate_5g8hz_temp: ax25_frame.payload.ax25_info.hk_data.chunk.rad_plate_5g8hz_temp
    :field tx_temp: ax25_frame.payload.ax25_info.hk_data.chunk.tx_temp
    :field rx_temp: ax25_frame.payload.ax25_info.hk_data.chunk.rx_temp
    :field bat_mbrd_temp: ax25_frame.payload.ax25_info.hk_data.chunk.bat_mbrd_temp
    :field ci_brd_temp: ax25_frame.payload.ax25_info.hk_data.chunk.ci_brd_temp
    :field panel_pos_y: ax25_frame.payload.ax25_info.hk_data.chunk.panel_pos_y
    :field panel_pos_x: ax25_frame.payload.ax25_info.hk_data.chunk.panel_pos_x
    :field panel_neg_x: ax25_frame.payload.ax25_info.hk_data.chunk.panel_neg_x
    :field obc_gpu_temp: ax25_frame.payload.ax25_info.hk_data.chunk.obc_gpu_temp
    :field panel_neg_y: ax25_frame.payload.ax25_info.hk_data.chunk.panel_neg_y
    :field accel_x: ax25_frame.payload.ax25_info.hk_data.chunk.accel_x
    :field accel_y: ax25_frame.payload.ax25_info.hk_data.chunk.accel_y
    :field accel_z: ax25_frame.payload.ax25_info.hk_data.chunk.accel_z
    :field ang_vcty_x: ax25_frame.payload.ax25_info.hk_data.chunk.ang_vcty_x
    :field ang_vcty_z: ax25_frame.payload.ax25_info.hk_data.chunk.ang_vcty_z
    :field raspi_last_exec: ax25_frame.payload.ax25_info.hk_data.chunk.raspi_last_exec
    :field raspi_mode: ax25_frame.payload.ax25_info.hk_data.chunk.raspi_mode
    :field eps_sw_1_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_1_volt
    :field eps_sw_1_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_1_curr
    :field eps_sw_2_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_2_volt
    :field eps_sw_2_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_2_curr
    :field eps_sw_5_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_5_volt
    :field eps_sw_5_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_5_curr
    :field eps_sw_6_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_6_volt
    :field eps_sw_6_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_6_curr
    :field eps_sw_7_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_7_volt
    :field eps_sw_7_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_7_curr
    :field eps_sw_8_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_8_volt
    :field eps_sw_8_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_8_curr
    :field eps_sw_9_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_9_volt
    :field eps_sw_10_volt: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_10_volt
    :field eps_sw_10_curr: ax25_frame.payload.ax25_info.hk_data.chunk.eps_sw_10_curr
    :field eps_3v3_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.eps_3v3_voltage
    :field eps_3v3_current: ax25_frame.payload.ax25_info.hk_data.chunk.eps_3v3_current
    :field eps_5v_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.eps_5v_voltage
    :field eps_5v_current: ax25_frame.payload.ax25_info.hk_data.chunk.eps_5v_current
    :field eps_12v_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.eps_12v_voltage
    :field eps_12v_current: ax25_frame.payload.ax25_info.hk_data.chunk.eps_12v_current
    :field bcr_1_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.bcr_1_voltage
    :field bcr_2_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.bcr_2_voltage
    :field bcr_3_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.bcr_3_voltage
    :field pwr5g8hz_12v_voltage: ax25_frame.payload.ax25_info.hk_data.chunk.pwr5g8hz_12v_voltage
    
    Attention: `rpt_callsign` cannot be accessed because `rpt_instance` is an
    array of unknown size at the beginning of the parsing process! Left an
    example in here.
    
    .. seealso::
       'http://www.origami.titech.ac.jp/wp/wp-content/uploads/2019/01/OP-S1-0115_FMDownLinkDataFormat_20190118.pdf'
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = self._root.Ax25Frame(self._io, self, self._root)

    class HkDataChunk3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ang_vcty_y_b1 = self._io.read_u1()
            self.ang_vcty_z = self._io.read_u2be()
            self.raspi_last_exec = self._io.read_u1()
            self.raspi_mode = self._io.read_u1()
            self.eps_sw_1_volt = self._io.read_u2be()
            self.eps_sw_1_curr = self._io.read_u2be()
            self.eps_sw_2_volt = self._io.read_u2be()
            self.eps_sw_2_curr = self._io.read_u2be()
            self.eps_sw_5_volt = self._io.read_u2be()
            self.eps_sw_5_curr = self._io.read_u2be()
            self.eps_sw_6_volt = self._io.read_u2be()
            self.eps_sw_6_curr = self._io.read_u2be()
            self.eps_sw_7_volt = self._io.read_u2be()
            self.eps_sw_7_curr = self._io.read_u2be()
            self.eps_sw_8_volt = self._io.read_u2be()
            self.eps_sw_8_curr = self._io.read_u2be()
            self.eps_sw_9_volt = self._io.read_u2be()
            self.eps_sw_9_curr_b0 = self._io.read_u1()


    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = self._root.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = self._root.IFrame(self._io, self, self._root)


    class HkDataChunk1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.last_exec_obc_id = self._io.read_u1()
            self.obc_cmd_status = self._io.read_u1()
            self.data_obtained_time_year = self._io.read_u1()
            self.data_obtained_time_month = self._io.read_u1()
            self.data_obtained_time_day = self._io.read_u1()
            self.data_obtained_time_hour = self._io.read_u1()
            self.data_obtained_time_minute = self._io.read_u1()
            self.data_obtained_time_second = self._io.read_u1()
            self.battery_voltage = self._io.read_u2be()
            self.battery_current = self._io.read_u2be()
            self.bat_status = self._io.read_u1()
            self.eps_sw_status = self._io.read_u2be()
            self.eps_bus_status = self._io.read_u1()
            self.satellite_mode = self._io.read_u1()
            self.sap_voltage = self._io.read_u2be()
            self.sap_current = self._io.read_u2be()
            self.sap_1_gen_pwr = self._io.read_u2be()
            self.sap_2_gen_pwr = self._io.read_u2be()
            self.sap_3_gen_pwr = self._io.read_u2be()
            self.sap_4_gen_pwr = self._io.read_u2be()
            self.sap_5_gen_pwr = self._io.read_u2be()
            self.sap_1_current_b0 = self._io.read_u1()


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            if (self.src_ssid_raw.ssid_mask & 1) == 0:
                self.repeater = self._root.Repeater(self._io, self, self._root)

            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            _on = self._io.size()
            if _on == 48:
                self.ax25_info = self._root.EchoBack(self._io, self, self._root)
            elif _on == 51:
                self.ax25_info = self._root.HkOrMissionData(self._io, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class HkDataChunk4(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.eps_sw_9_curr_b1 = self._io.read_u1()
            self.eps_sw_10_volt = self._io.read_u2be()
            self.eps_sw_10_curr = self._io.read_u2be()
            self.eps_3v3_voltage = self._io.read_u2be()
            self.eps_3v3_current = self._io.read_u2be()
            self.eps_5v_voltage = self._io.read_u2be()
            self.eps_5v_current = self._io.read_u2be()
            self.eps_12v_voltage = self._io.read_u2be()
            self.eps_12v_current = self._io.read_u2be()
            self.bcr_1_voltage = self._io.read_u2be()
            self.bcr_2_voltage = self._io.read_u2be()
            self.bcr_3_voltage = self._io.read_u2be()
            self.sap_5_current = self._io.read_u2be()
            self.pwr5g8hz_12v_voltage = self._io.read_u1()


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class HkOrMissionData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pkt_num = [None] * (3)
            for i in range(3):
                self.pkt_num[i] = self._io.read_u1()

            if  ((self.pkt_num[0] == self.pkt_num[1]) and (self.pkt_num[1] == self.pkt_num[2])) :
                self.hk_data = self._root.HkData(self._io, self, self._root)

            if self.pkt_num[0] != self.pkt_num[1]:
                self._raw_mission_data = self._io.read_bytes(32)
                io = KaitaiStream(BytesIO(self._raw_mission_data))
                self.mission_data = self._root.MissionData(io, self, self._root)


        @property
        def packet_number(self):
            if hasattr(self, '_m_packet_number'):
                return self._m_packet_number if hasattr(self, '_m_packet_number') else None

            self._m_packet_number = ((self.pkt_num[0] | self.pkt_num[1]) | self.pkt_num[2])
            return self._m_packet_number if hasattr(self, '_m_packet_number') else None


    class HkData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = (self._parent.packet_number % 4)
            if _on == 0:
                self._raw_chunk = self._io.read_bytes_full()
                io = KaitaiStream(BytesIO(self._raw_chunk))
                self.chunk = self._root.HkDataChunk4(io, self, self._root)
            elif _on == 1:
                self._raw_chunk = self._io.read_bytes_full()
                io = KaitaiStream(BytesIO(self._raw_chunk))
                self.chunk = self._root.HkDataChunk1(io, self, self._root)
            elif _on == 3:
                self._raw_chunk = self._io.read_bytes_full()
                io = KaitaiStream(BytesIO(self._raw_chunk))
                self.chunk = self._root.HkDataChunk3(io, self, self._root)
            elif _on == 2:
                self._raw_chunk = self._io.read_bytes_full()
                io = KaitaiStream(BytesIO(self._raw_chunk))
                self.chunk = self._root.HkDataChunk2(io, self, self._root)
            else:
                self.chunk = self._io.read_bytes_full()


    class Repeaters(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.rpt_ssid_raw = self._root.SsidMask(self._io, self, self._root)


    class Repeater(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_instance = []
            i = 0
            while True:
                _ = self._root.Repeaters(self._io, self, self._root)
                self.rpt_instance.append(_)
                if (_.rpt_ssid_raw.ssid_mask & 1) == 1:
                    break
                i += 1


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            io = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = self._root.Callsign(io, self, self._root)


    class HkDataChunk2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sap_1_current_b1 = self._io.read_u1()
            self.sap_2_current = self._io.read_u2be()
            self.sap_3_current = self._io.read_u2be()
            self.sap_4_current = self._io.read_u2be()
            self.eps_temp = self._io.read_u2be()
            self.obc_temp_0 = self._io.read_u1()
            self.obc_temp_1 = self._io.read_u1()
            self.amp_5g8hz_temp = self._io.read_u1()
            self.rad_plate_5g8hz_temp = self._io.read_u1()
            self.tx_temp = self._io.read_u1()
            self.rx_temp = self._io.read_u1()
            self.bat_mbrd_temp = self._io.read_u2be()
            self.ci_brd_temp = self._io.read_u1()
            self.panel_pos_y = self._io.read_u1()
            self.panel_pos_x = self._io.read_u1()
            self.panel_neg_x = self._io.read_u1()
            self.obc_gpu_temp = self._io.read_u1()
            self.panel_neg_y = self._io.read_u1()
            self.accel_x = self._io.read_u2be()
            self.accel_y = self._io.read_u2be()
            self.accel_z = self._io.read_u2be()
            self.ang_vcty_x = self._io.read_u2be()
            self.ang_vcty_y_b0 = self._io.read_u1()


    class EchoBack(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.response_data = self._io.read_bytes(32)


    class MissionData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.unparsed = self._io.read_bytes_full()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO
import satnogsdecoders.process


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Elfin(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field beacon_setting: ax25_frame.payload.ax25_info.beacon_setting
    :field status_1_safe_mode: ax25_frame.payload.ax25_info.status_1_safe_mode
    :field status_1_reserved: ax25_frame.payload.ax25_info.status_1_reserved
    :field status_1_early_orbit: ax25_frame.payload.ax25_info.status_1_early_orbit
    :field status_2_payload_power: ax25_frame.payload.ax25_info.status_2_payload_power
    :field status_2_9v_boost: ax25_frame.payload.ax25_info.status_2_9v_boost
    :field status_2_bat_htr_allow: ax25_frame.payload.ax25_info.
    :field status_2_htr_force: ax25_frame.payload.ax25_info.status_2_htr_force
    :field status_2_htr_alert: ax25_frame.payload.ax25_info.status_2_htr_alert
    :field status_2_reserved: ax25_frame.payload.ax25_info.status_2_reserved
    :field reserved: ax25_frame.payload.ax25_info.reserved
    :field hskp_pwr1_rtcc_year: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_year
    :field hskp_pwr1_rtcc_month: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_month
    :field hskp_pwr1_rtcc_day: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_day
    :field hskp_pwr1_rtcc_hour: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_hour
    :field hskp_pwr1_rtcc_minute: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_minute
    :field hskp_pwr1_rtcc_second: ax25_frame.payload.ax25_info.hskp_pwr1_rtcc_second
    :field hskp_pwr1_adc_data_adc_sa_volt_12: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_adc_sa_volt_12
    :field hskp_pwr1_adc_data_adc_sa_volt_34: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_adc_sa_volt_34
    :field hskp_pwr1_adc_data_adc_sa_volt_56: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_adc_sa_volt_56
    :field hskp_pwr1_adc_data_sa_short_circuit_current: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_sa_short_circuit_current
    :field hskp_pwr1_adc_data_bat_2_volt: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_bat_2_volt
    :field hskp_pwr1_adc_data_bat_1_volt: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_bat_1_volt
    :field hskp_pwr1_adc_data_reg_sa_volt_1: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_reg_sa_volt_1
    :field hskp_pwr1_adc_data_reg_sa_volt_2: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_reg_sa_volt_2
    :field hskp_pwr1_adc_data_reg_sa_volt_3: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_reg_sa_volt_3
    :field hskp_pwr1_adc_data_power_bus_current_1: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_power_bus_current_1
    :field hskp_pwr1_adc_data_power_bus_current_2: ax25_frame.payload.ax25_info.hskp_pwr1_adc_data_power_bus_current_2
    :field hskp_pwr1_bat_mon_1_avg_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_1_avg_cur_reg
    :field hskp_pwr1_bat_mon_1_temperature_register: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_1_temperature_register
    :field hskp_pwr1_bat_mon_1_volt_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_1_volt_reg
    :field hskp_pwr1_bat_mon_1_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_1_cur_reg
    :field hskp_pwr1_bat_mon_1_acc_curr_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_1_acc_curr_reg
    :field hskp_pwr1_bat_mon_2_avg_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_2_avg_cur_reg
    :field hskp_pwr1_bat_mon_2_temperature_register: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_2_temperature_register
    :field hskp_pwr1_bat_mon_2_volt_reg: ax2_frame.payload.ax25_info.hskp_pwr1_bat_mon_2_volt_reg
    :field hskp_pwr1_bat_mon_2_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_2_cur_reg
    :field hskp_pwr1_bat_mon_2_acc_curr_reg: ax25_frame.payload.ax25_info.hskp_pwr1_bat_mon_2_acc_curr_reg
    :field hskp_pwr1_bv_mon: ax25_frame.payload.ax25_info.hskp_pwr1_bv_mon
    :field hskp_pwr1_tmps_tmp1: ax25_frame.payload.ax25_info.hskp_pwr1_tmps_tmp1
    :field hskp_pwr1_tmps_tmp2: ax25_frame.payload.ax25_info.hskp_pwr1_tmps_tmp2
    :field hskp_pwr1_tmps_tmp3: ax25_frame.payload.ax25_info.hskp_pwr1_tmps_tmp3
    :field hskp_pwr1_tmps_tmp4: ax25_frame.payload.ax25_info.hskp_pwr1_tmps_tmp4
    :field hskp_pwr1_accumulated_curr_bat1_rarc: ax25_frame.payload.ax25_info.hskp_pwr1_accumulated_curr_bat1_rarc
    :field hskp_pwr1_accumulated_curr_bat1_rsrc: ax25_frame.payload.ax25_info.hskp_pwr1_accumulated_curr_bat1_rsrc
    :field hskp_pwr1_accumulated_curr_bat2_rarc: ax25_frame.payload.ax25_info.hskp_pwr1_accumulated_curr_bat2_rarc
    :field hskp_pwr1_accumulated_curr_bat2_rsrc: ax25_frame.payload.ax25_info.hskp_pwr1_accumulated_curr_bat2_rsrc
    :field hskp_pwr2_rtcc_year: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_year
    :field hskp_pwr2_rtcc_month: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_month
    :field hskp_pwr2_rtcc_day: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_day
    :field hskp_pwr2_rtcc_hour: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_hour
    :field hskp_pwr2_rtcc_minute: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_minute
    :field hskp_pwr2_rtcc_second: ax25_frame.payload.ax25_info.hskp_pwr2_rtcc_second
    :field hskp_pwr2_adc_data_adc_sa_volt_12: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_adc_sa_volt_12
    :field hskp_pwr2_adc_data_adc_sa_volt_34: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_adc_sa_volt_34
    :field hskp_pwr2_adc_data_adc_sa_volt_56: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_adc_sa_volt_56
    :field hskp_pwr2_adc_data_sa_short_circuit_current: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_sa_short_circuit_current
    :field hskp_pwr2_adc_data_bat_2_volt: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_bat_2_volt
    :field hskp_pwr2_adc_data_bat_1_volt: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_bat_1_volt
    :field hskp_pwr2_adc_data_reg_sa_volt_1: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_reg_sa_volt_1
    :field hskp_pwr2_adc_data_reg_sa_volt_2: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_reg_sa_volt_2
    :field hskp_pwr2_adc_data_reg_sa_volt_3: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_reg_sa_volt_3
    :field hskp_pwr2_adc_data_power_bus_current_1: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_power_bus_current_1
    :field hskp_pwr2_adc_data_power_bus_current_2: ax25_frame.payload.ax25_info.hskp_pwr2_adc_data_power_bus_current_2
    :field hskp_pwr2_bat_mon_1_avg_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_1_avg_cur_reg
    :field hskp_pwr2_bat_mon_1_temperature_register: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_1_temperature_register
    :field hskp_pwr2_bat_mon_1_volt_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_1_volt_reg
    :field hskp_pwr2_bat_mon_1_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_1_cur_reg
    :field hskp_pwr2_bat_mon_1_acc_curr_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_1_acc_curr_reg
    :field hskp_pwr2_bat_mon_2_avg_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_2_avg_cur_reg
    :field hskp_pwr2_bat_mon_2_temperature_register: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_2_temperature_register
    :field hskp_pwr2_bat_mon_2_volt_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_2_volt_reg
    :field hskp_pwr2_bat_mon_2_cur_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_2_cur_reg
    :field hskp_pwr2_bat_mon_2_acc_curr_reg: ax25_frame.payload.ax25_info.hskp_pwr2_bat_mon_2_acc_curr_reg
    :field hskp_pwr2_bv_mon: ax25_frame.payload.ax25_info.hskp_pwr2_bv_mon
    :field hskp_pwr2_tmps_tmp1: ax25_frame.payload.ax25_info.hskp_pwr2_tmps_tmp1
    :field hskp_pwr2_tmps_tmp2: ax25_frame.payload.ax25_info.hskp_pwr2_tmps_tmp2
    :field hskp_pwr2_tmps_tmp3: ax25_frame.payload.ax25_info.hskp_pwr2_tmps_tmp3
    :field hskp_pwr2_tmps_tmp4: ax25_frame.payload.ax25_info.hskp_pwr2_tmps_tmp4
    :field hskp_pwr2_accumulated_curr_bat1_rarc: ax25_frame.payload.ax25_info.hskp_pwr2_accumulated_curr_bat1_rarc
    :field hskp_pwr2_accumulated_curr_bat1_rsrc: ax25_frame.payload.ax25_info.hskp_pwr2_accumulated_curr_bat1_rsrc
    :field hskp_pwr2_accumulated_curr_bat2_rarc: ax25_frame.payload.ax25_info.hskp_pwr2_accumulated_curr_bat2_rarc
    :field hskp_pwr2_accumulated_curr_bat2_rsrc: ax25_frame.payload.ax25_info.hskp_pwr2_accumulated_curr_bat2_rsrc
    :field acb_pc_data1_rtcc_year: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_year
    :field acb_pc_data1_rtcc_month: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_month
    :field acb_pc_data1_rtcc_day: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_day
    :field acb_pc_data1_rtcc_hour: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_hour
    :field acb_pc_data1_rtcc_minute: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_minute
    :field acb_pc_data1_rtcc_second: ax25_frame.payload.ax25_info.acb_pc_data1_rtcc_second
    :field acb_pc_data1_acb_mrm_x: ax25_frame.payload.ax25_info.acb_pc_data1_acb_mrm_x
    :field acb_pc_data1_acb_mrm_y: ax25_frame.payload.ax25_info.acb_pc_data1_acb_mrm_y
    :field acb_pc_data1_acb_mrm_z: ax25_frame.payload.ax25_info.acb_pc_data1_acb_mrm_z
    :field acb_pc_data1_ipdu_mrm_x: ax25_frame.payload.ax25_info.acb_pc_data1_ipdu_mrm_x
    :field acb_pc_data1_ipdu_mrm_y: ax25_frame.payload.ax25_info.acb_pc_data1_ipdu_mrm_y
    :field acb_pc_data1_ipdu_mrm_z: ax25_frame.payload.ax25_info.acb_pc_data1_ipdu_mrm_z
    :field acb_pc_data1_tmps_tmp1: ax25_frame.payload.ax25_info.acb_pc_data1_tmps_tmp1
    :field acb_pc_data1_tmps_tmp2: ax25_frame.payload.ax25_info.acb_pc_data1_tmps_tmp2
    :field acb_pc_data1_tmps_tmp3: ax25_frame.payload.ax25_info.acb_pc_data1_tmps_tmp3
    :field acb_pc_data1_tmps_tmp4: ax25_frame.payload.ax25_info.acb_pc_data1_tmps_tmp4
    :field acb_pc_data2_rtcc_year: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_year
    :field acb_pc_data2_rtcc_month: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_month
    :field acb_pc_data2_rtcc_day: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_day
    :field acb_pc_data2_rtcc_hour: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_hour
    :field acb_pc_data2_rtcc_minute: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_minute
    :field acb_pc_data2_rtcc_second: ax25_frame.payload.ax25_info.acb_pc_data2_rtcc_second
    :field acb_pc_data2_acb_mrm_x: ax25_frame.payload.ax25_info.acb_pc_data2_acb_mrm_x
    :field acb_pc_data2_acb_mrm_y: ax25_frame.payload.ax25_info.acb_pc_data2_acb_mrm_y
    :field acb_pc_data2_acb_mrm_z: ax25_frame.payload.ax25_info.acb_pc_data2_acb_mrm_z
    :field acb_pc_data2_ipdu_mrm_x: ax25_frame.payload.ax25_info.acb_pc_data2_ipdu_mrm_x
    :field acb_pc_data2_ipdu_mrm_y: ax25_frame.payload.ax25_info.acb_pc_data2_ipdu_mrm_y
    :field acb_pc_data2_ipdu_mrm_z: ax25_frame.payload.ax25_info.acb_pc_data2_ipdu_mrm_z
    :field acb_pc_data2_tmps_tmp1: ax25_frame.payload.ax25_info.acb_pc_data2_tmps_tmp1
    :field acb_pc_data2_tmps_tmp2: ax25_frame.payload.ax25_info.acb_pc_data2_tmps_tmp2
    :field acb_pc_data2_tmps_tmp3: ax25_frame.payload.ax25_info.acb_pc_data2_tmps_tmp3
    :field acb_pc_data2_tmps_tmp4: ax25_frame.payload.ax25_info.acb_pc_data2_tmps_tmp4
    :field acb_sense_adc_data_current: ax25_frame.payload.ax25_info.acb_sense_adc_data_current
    :field acb_sense_adc_data_voltage: ax25_frame.payload.ax25_info.acb_sense_adc_data_voltage
    :field fc_counters_cmds_recv: ax25_frame.payload.ax25_info.fc_counters_cmds_recv
    :field fc_counters_badcmds_recv: ax25_frame.payload.ax25_info.fc_counters_badcmds_recv
    :field fc_counters_badpkts_fm_radio: ax25_frame.payload.ax25_info.fc_counters_badpkts_fm_radio
    :field fc_counters_fcpkts_fm_radio: ax25_frame.payload.ax25_info.fc_counters_fcpkts_fm_radio
    :field fc_counters_errors: ax25_frame.payload.ax25_info.fc_counters_errors
    :field fc_counters_reboots: ax25_frame.payload.ax25_info.fc_counters_reboots
    :field fc_counters_intrnl_wdttmout: ax25_frame.payload.ax25_info.fc_counters_intrnl_wdttmout
    :field fc_counters_brwnouts: ax25_frame.payload.ax25_info.fc_counters_brwnouts
    :field fc_counters_wdpicrst: ax25_frame.payload.ax25_info.fc_counters_wdpicrst
    :field fc_counters_porst: ax25_frame.payload.ax25_info.fc_counters_porst
    :field fc_counters_uart1_recvpkts: ax25_frame.payload.ax25_info.fc_counters_uart1_recvpkts
    :field fc_counters_uart1_parseerrs: ax25_frame.payload.ax25_info.fc_counters_uart1_parseerrs
    :field fc_counters_sips_ovcur_evts: ax25_frame.payload.ax25_info.fc_counters_sips_ovcur_evts
    :field fc_counters_vu1_on: ax25_frame.payload.ax25_info.fc_counters_vu1_on
    :field fc_counters_vu1_off: ax25_frame.payload.ax25_info.fc_counters_vu1_off
    :field fc_counters_vu2_on: ax25_frame.payload.ax25_info.fc_counters_vu2_on
    :field fc_counters_vu2_off: ax25_frame.payload.ax25_info.fc_counters_vu2_off
    :field radio_tlm_rssi: ax25_frame.payload.ax25_info.radio_tlm_rssi
    :field radio_tlm_bytes_rx: ax25_frame.payload.ax25_info.radio_tlm_bytes_rx
    :field radio_tlm_bytes_tx: ax25_frame.payload.ax25_info.radio_tlm_bytes_tx
    :field radio_cfg_read_radio_palvl: ax25_frame.payload.ax25_info.radio_cfg_read_radio_palvl
    :field errors_error1_day: ax25_frame.payload.ax25_info.errors_error1_day
    :field errors_error1_hour: ax25_frame.payload.ax25_info.errors_error1_hour
    :field errors_error1_minute: ax25_frame.payload.ax25_info.errors_error1_minute
    :field errors_error1_second: ax25_frame.payload.ax25_info.errors_error1_second
    :field errors_error1_error: ax25_frame.payload.ax25_info.errors_error1_error
    :field errors_error2_day: ax25_frame.payload.ax25_info.errors_error2_day
    :field errors_error2_hour: ax25_frame.payload.ax25_info.errors_error2_hour
    :field errors_error2_minute: ax25_frame.payload.ax25_info.errors_error2_minute
    :field errors_error2_second: ax25_frame.payload.ax25_info.errors_error2_second
    :field errors_error2_error: ax25_frame.payload.ax25_info.errors_error2_error
    :field errors_error3_day: ax25_frame.payload.ax25_info.errors_error3_day
    :field errors_error3_hour: ax25_frame.payload.ax25_info.errors_error3_hour
    :field errors_error3_minute: ax25_frame.payload.ax25_info.errors_error3_minute
    :field errors_error3_second: ax25_frame.payload.ax25_info.errors_error3_second
    :field errors_error3_error: ax25_frame.payload.ax25_info.errors_error3_error
    :field errors_error4_day: ax25_frame.payload.ax25_info.errors_error4_day
    :field errors_error4_hour: ax25_frame.payload.ax25_info.errors_error4_hour
    :field errors_error4_minute: ax25_frame.payload.ax25_info.errors_error4_minute
    :field errors_error4_second: ax25_frame.payload.ax25_info.errors_error4_second
    :field errors_error4_error: ax25_frame.payload.ax25_info.errors_error4_error
    :field errors_error5_day: ax25_frame.payload.ax25_info.errors_error5_day
    :field errors_error5_hour: ax25_frame.payload.ax25_info.errors_error5_hour
    :field errors_error5_minute: ax25_frame.payload.ax25_info.errors_error5_minute
    :field errors_error5_second: ax25_frame.payload.ax25_info.errors_error5_second
    :field errors_error5_error: ax25_frame.payload.ax25_info.errors_error5_error
    :field errors_error6_day: ax25_frame.payload.ax25_info.errors_error6_day
    :field errors_error6_hour: ax25_frame.payload.ax25_info.errors_error6_hour
    :field errors_error6_minute: ax25_frame.payload.ax25_info.errors_error6_minute
    :field errors_error6_second: ax25_frame.payload.ax25_info.errors_error6_second
    :field errors_error6_error: ax25_frame.payload.ax25_info.errors_error6_error
    :field errors_error7_day: ax25_frame.payload.ax25_info.errors_error7_day
    :field errors_error7_hour: ax25_frame.payload.ax25_info.errors_error7_hour
    :field errors_error7_minute: ax25_frame.payload.ax25_info.errors_error7_minute
    :field errors_error7_second: ax25_frame.payload.ax25_info.errors_error7_second
    :field errors_error7_error: ax25_frame.payload.ax25_info.errors_error7_error
    :field fc_salt: ax25_frame.payload.ax25_info.fc_salt
    :field fc_crc: ax25_frame.payload.ax25_info.fc_crc
    :field fc_status_safe_mode: ax25_frame.payload.ax25_info.fc_status_safe_mode
    :field fc_status_reserved: ax25_frame.payload.ax25_info.fc_status_reserved
    :field fc_status_early_orbit: ax25_frame.payload.ax25_info.fc_status_early_orbit
    :field opcode: ax25_frame.payload.ax25_info.opcode
    :field hskp_pwr1_rtcc_year: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_year
    :field hskp_pwr1_rtcc_month: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_month
    :field hskp_pwr1_rtcc_day: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_day
    :field hskp_pwr1_rtcc_hour: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_hour
    :field hskp_pwr1_rtcc_minute: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_minute
    :field hskp_pwr1_rtcc_second: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_rtcc_second
    :field hskp_pwr1_pwr_board_id: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_pwr_board_id
    :field hskp_pwr1_adc_data_adc_sa_volt_12: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_adc_sa_volt_12
    :field hskp_pwr1_adc_data_adc_sa_volt_34: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_adc_sa_volt_34
    :field hskp_pwr1_adc_data_adc_sa_volt_56: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_adc_sa_volt_56
    :field hskp_pwr1_adc_data_sa_short_circuit_current: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_sa_short_circuit_current
    :field hskp_pwr1_adc_data_bat_2_volt: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_bat_2_volt
    :field hskp_pwr1_adc_data_bat_1_volt: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_bat_1_volt
    :field hskp_pwr1_adc_data_reg_sa_volt_1: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_reg_sa_volt_1
    :field hskp_pwr1_adc_data_reg_sa_volt_2: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_reg_sa_volt_2
    :field hskp_pwr1_adc_data_reg_sa_volt_3: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_reg_sa_volt_3
    :field hskp_pwr1_adc_data_power_bus_current_1: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_power_bus_current_1
    :field hskp_pwr1_adc_data_power_bus_current_2: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_adc_data_power_bus_current_2
    :field hskp_pwr1_bat_mon_1_avg_cur_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_1_avg_cur_reg
    :field hskp_pwr1_bat_mon_1_temperature_register: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_1_temperature_register
    :field hskp_pwr1_bat_mon_1_volt_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_1_volt_reg
    :field hskp_pwr1_bat_mon_1_cur_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_1_cur_reg
    :field hskp_pwr1_bat_mon_1_acc_curr_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_1_acc_curr_reg
    :field hskp_pwr1_bat_mon_2_avg_cur_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_2_avg_cur_reg
    :field hskp_pwr1_bat_mon_2_temperature_register: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_2_temperature_register
    :field hskp_pwr1_bat_mon_2_volt_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_2_volt_reg
    :field hskp_pwr1_bat_mon_2_cur_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_2_cur_reg
    :field hskp_pwr1_bat_mon_2_acc_curr_reg: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bat_mon_2_acc_curr_reg
    :field hskp_pwr1_bv_mon: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_bv_mon
    :field hskp_pwr1_tmps_tmp1: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_tmps_tmp1
    :field hskp_pwr1_tmps_tmp2: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_tmps_tmp2
    :field hskp_pwr1_tmps_tmp3: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_tmps_tmp3
    :field hskp_pwr1_tmps_tmp4: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_tmps_tmp4
    :field hskp_pwr1_accumulated_curr_bat1_rsrc: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_accumulated_curr_bat1_rsrc
    :field hskp_pwr1_accumulated_curr_bat2_rsrc: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_accumulated_curr_bat2_rsrc
    :field hskp_pwr1_accumulated_curr_bat1_rarc: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_accumulated_curr_bat1_rarc
    :field hskp_pwr1_accumulated_curr_bat2_rarc: ax25_frame.payload.ax25_info.cmd_response.hskp_pwr1_accumulated_curr_bat2_rarc
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = self._root.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = self._root.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = self._root.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            _on = self._io.size()
            if _on == 269:
                self._raw__raw_ax25_info = self._io.read_bytes_full()
                _process = satnogsdecoders.process.ElfinPp()
                self._raw_ax25_info = _process.decode(self._raw__raw_ax25_info)
                io = KaitaiStream(BytesIO(self._raw_ax25_info))
                self.ax25_info = self._root.TlmData(io, self, self._root)
            else:
                self._raw__raw_ax25_info = self._io.read_bytes_full()
                _process = satnogsdecoders.process.ElfinPp()
                self._raw_ax25_info = _process.decode(self._raw__raw_ax25_info)
                io = KaitaiStream(BytesIO(self._raw_ax25_info))
                self.ax25_info = self._root.CmdResponse(io, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class HskpPacket(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.hskp_pwr1_rtcc_year = self._io.read_u1()
            self.hskp_pwr1_rtcc_month = self._io.read_u1()
            self.hskp_pwr1_rtcc_day = self._io.read_u1()
            self.hskp_pwr1_rtcc_hour = self._io.read_u1()
            self.hskp_pwr1_rtcc_minute = self._io.read_u1()
            self.hskp_pwr1_rtcc_second = self._io.read_u1()
            self.hskp_pwr1_pwr_board_id = self._io.read_u1()
            self.hskp_pwr1_adc_data_adc_sa_volt_12 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_adc_sa_volt_34 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_adc_sa_volt_56 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_sa_short_circuit_current = self._io.read_u2be()
            self.hskp_pwr1_adc_data_bat_2_volt = self._io.read_u2be()
            self.hskp_pwr1_adc_data_bat_1_volt = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_1 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_2 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_3 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_power_bus_current_1 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_power_bus_current_2 = self._io.read_u2be()
            self.hskp_pwr1_bat_mon_1_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_temperature_register = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_volt_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_temperature_register = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_volt_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr1_bv_mon = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp1 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp2 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp3 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp4 = self._io.read_s2be()
            self.hskp_pwr1_accumulated_curr_bat1_rsrc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat2_rsrc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat1_rarc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat2_rarc = self._io.read_u1()
            self.fc_status_early_orbit = self._io.read_bits_int(4)
            self.fc_status_reserved = self._io.read_bits_int(3)
            self.fc_status_safe_mode = self._io.read_bits_int(1) != 0


    class CmdResponse(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.frame_start = self._io.ensure_fixed_contents(b"\x93")
            self.opcode = self._io.read_u1()
            _on = self.opcode
            if _on == 48:
                self.cmd_response = self._root.HskpPacket(self._io, self, self._root)
            self.fc_crc = self._io.read_u1()
            self.frame_end = self._io.ensure_fixed_contents(b"\x5E")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            io = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = self._root.Callsign(io, self, self._root)


    class TlmData(KaitaiStruct):
        """
        .. seealso::
           Source - https://elfin.igpp.ucla.edu/s/Beacon-Format_v2.xlsx
        """
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.frame_start = self._io.ensure_fixed_contents(b"\x93")
            self.beacon_setting = self._io.read_u1()
            self.status_1_early_orbit = self._io.read_bits_int(4)
            self.status_1_reserved = self._io.read_bits_int(3)
            self.status_1_safe_mode = self._io.read_bits_int(1) != 0
            self.status_2_reserved = self._io.read_bits_int(3)
            self.status_2_htr_alert = self._io.read_bits_int(1) != 0
            self.status_2_htr_force = self._io.read_bits_int(1) != 0
            self.status_2_bat_htr_allow = self._io.read_bits_int(1) != 0
            self.status_2_9v_boost = self._io.read_bits_int(1) != 0
            self.status_2_payload_power = self._io.read_bits_int(1) != 0
            self._io.align_to_byte()
            self.reserved = self._io.read_u1()
            self.hskp_pwr1_rtcc_year = self._io.read_u1()
            self.hskp_pwr1_rtcc_month = self._io.read_u1()
            self.hskp_pwr1_rtcc_day = self._io.read_u1()
            self.hskp_pwr1_rtcc_hour = self._io.read_u1()
            self.hskp_pwr1_rtcc_minute = self._io.read_u1()
            self.hskp_pwr1_rtcc_second = self._io.read_u1()
            self.hskp_pwr1_adc_data_adc_sa_volt_12 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_adc_sa_volt_34 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_adc_sa_volt_56 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_sa_short_circuit_current = self._io.read_u2be()
            self.hskp_pwr1_adc_data_bat_2_volt = self._io.read_u2be()
            self.hskp_pwr1_adc_data_bat_1_volt = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_1 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_2 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_reg_sa_volt_3 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_power_bus_current_1 = self._io.read_u2be()
            self.hskp_pwr1_adc_data_power_bus_current_2 = self._io.read_u2be()
            self.hskp_pwr1_bat_mon_1_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_temperature_register = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_volt_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_1_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_temperature_register = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_volt_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_cur_reg = self._io.read_s2be()
            self.hskp_pwr1_bat_mon_2_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr1_bv_mon = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp1 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp2 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp3 = self._io.read_s2be()
            self.hskp_pwr1_tmps_tmp4 = self._io.read_s2be()
            self.hskp_pwr1_accumulated_curr_bat1_rarc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat1_rsrc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat2_rarc = self._io.read_u1()
            self.hskp_pwr1_accumulated_curr_bat2_rsrc = self._io.read_u1()
            self.hskp_pwr2_rtcc_year = self._io.read_u1()
            self.hskp_pwr2_rtcc_month = self._io.read_u1()
            self.hskp_pwr2_rtcc_day = self._io.read_u1()
            self.hskp_pwr2_rtcc_hour = self._io.read_u1()
            self.hskp_pwr2_rtcc_minute = self._io.read_u1()
            self.hskp_pwr2_rtcc_second = self._io.read_u1()
            self.hskp_pwr2_adc_data_adc_sa_volt_12 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_adc_sa_volt_34 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_adc_sa_volt_56 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_sa_short_circuit_current = self._io.read_u2be()
            self.hskp_pwr2_adc_data_bat_2_volt = self._io.read_u2be()
            self.hskp_pwr2_adc_data_bat_1_volt = self._io.read_u2be()
            self.hskp_pwr2_adc_data_reg_sa_volt_1 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_reg_sa_volt_2 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_reg_sa_volt_3 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_power_bus_current_1 = self._io.read_u2be()
            self.hskp_pwr2_adc_data_power_bus_current_2 = self._io.read_u2be()
            self.hskp_pwr2_bat_mon_1_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_1_temperature_register = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_1_volt_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_1_cur_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_1_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_2_avg_cur_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_2_temperature_register = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_2_volt_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_2_cur_reg = self._io.read_s2be()
            self.hskp_pwr2_bat_mon_2_acc_curr_reg = self._io.read_s2be()
            self.hskp_pwr2_bv_mon = self._io.read_s2be()
            self.hskp_pwr2_tmps_tmp1 = self._io.read_s2be()
            self.hskp_pwr2_tmps_tmp2 = self._io.read_s2be()
            self.hskp_pwr2_tmps_tmp3 = self._io.read_s2be()
            self.hskp_pwr2_tmps_tmp4 = self._io.read_s2be()
            self.hskp_pwr2_accumulated_curr_bat1_rarc = self._io.read_u1()
            self.hskp_pwr2_accumulated_curr_bat1_rsrc = self._io.read_u1()
            self.hskp_pwr2_accumulated_curr_bat2_rarc = self._io.read_u1()
            self.hskp_pwr2_accumulated_curr_bat2_rsrc = self._io.read_u1()
            self.acb_pc_data1_rtcc_year = self._io.read_u1()
            self.acb_pc_data1_rtcc_month = self._io.read_u1()
            self.acb_pc_data1_rtcc_day = self._io.read_u1()
            self.acb_pc_data1_rtcc_hour = self._io.read_u1()
            self.acb_pc_data1_rtcc_minute = self._io.read_u1()
            self.acb_pc_data1_rtcc_second = self._io.read_u1()
            self.acb_pc_data1_acb_mrm_x = self._io.read_s2be()
            self.acb_pc_data1_acb_mrm_y = self._io.read_s2be()
            self.acb_pc_data1_acb_mrm_z = self._io.read_s2be()
            self.acb_pc_data1_ipdu_mrm_x = self._io.read_s2be()
            self.acb_pc_data1_ipdu_mrm_y = self._io.read_s2be()
            self.acb_pc_data1_ipdu_mrm_z = self._io.read_s2be()
            self.acb_pc_data1_tmps_tmp1 = self._io.read_s2be()
            self.acb_pc_data1_tmps_tmp2 = self._io.read_s2be()
            self.acb_pc_data1_tmps_tmp3 = self._io.read_s2be()
            self.acb_pc_data1_tmps_tmp4 = self._io.read_s2be()
            self.acb_pc_data2_rtcc_year = self._io.read_u1()
            self.acb_pc_data2_rtcc_month = self._io.read_u1()
            self.acb_pc_data2_rtcc_day = self._io.read_u1()
            self.acb_pc_data2_rtcc_hour = self._io.read_u1()
            self.acb_pc_data2_rtcc_minute = self._io.read_u1()
            self.acb_pc_data2_rtcc_second = self._io.read_u1()
            self.acb_pc_data2_acb_mrm_x = self._io.read_s2be()
            self.acb_pc_data2_acb_mrm_y = self._io.read_s2be()
            self.acb_pc_data2_acb_mrm_z = self._io.read_s2be()
            self.acb_pc_data2_ipdu_mrm_x = self._io.read_s2be()
            self.acb_pc_data2_ipdu_mrm_y = self._io.read_s2be()
            self.acb_pc_data2_ipdu_mrm_z = self._io.read_s2be()
            self.acb_pc_data2_tmps_tmp1 = self._io.read_s2be()
            self.acb_pc_data2_tmps_tmp2 = self._io.read_s2be()
            self.acb_pc_data2_tmps_tmp3 = self._io.read_s2be()
            self.acb_pc_data2_tmps_tmp4 = self._io.read_s2be()
            self.acb_sense_adc_data_current = self._io.read_u2le()
            self.acb_sense_adc_data_voltage = self._io.read_u2le()
            self.fc_counters_cmds_recv = self._io.read_u1()
            self.fc_counters_badcmds_recv = self._io.read_u1()
            self.fc_counters_badpkts_fm_radio = self._io.read_u1()
            self.fc_counters_fcpkts_fm_radio = self._io.read_u1()
            self.fc_counters_errors = self._io.read_u1()
            self.fc_counters_reboots = self._io.read_u1()
            self.fc_counters_intrnl_wdttmout = self._io.read_u1()
            self.fc_counters_brwnouts = self._io.read_u1()
            self.fc_counters_wdpicrst = self._io.read_u1()
            self.fc_counters_porst = self._io.read_u1()
            self.fc_counters_uart1_recvpkts = self._io.read_u1()
            self.fc_counters_uart1_parseerrs = self._io.read_u1()
            self.fc_counters_sips_ovcur_evts = self._io.read_u1()
            self.fc_counters_vu1_on = self._io.read_u1()
            self.fc_counters_vu1_off = self._io.read_u1()
            self.fc_counters_vu2_on = self._io.read_u1()
            self.fc_counters_vu2_off = self._io.read_u1()
            self.radio_tlm_rssi = self._io.read_u1()
            self.radio_tlm_bytes_rx = self._io.read_u4be()
            self.radio_tlm_bytes_tx = self._io.read_u4be()
            self.radio_cfg_read_radio_palvl = self._io.read_u1()
            self.errors_error1_day = self._io.read_u1()
            self.errors_error1_hour = self._io.read_u1()
            self.errors_error1_minute = self._io.read_u1()
            self.errors_error1_second = self._io.read_u1()
            self.errors_error1_error = self._io.read_u1()
            self.errors_error2_day = self._io.read_u1()
            self.errors_error2_hour = self._io.read_u1()
            self.errors_error2_minute = self._io.read_u1()
            self.errors_error2_second = self._io.read_u1()
            self.errors_error2_error = self._io.read_u1()
            self.errors_error3_day = self._io.read_u1()
            self.errors_error3_hour = self._io.read_u1()
            self.errors_error3_minute = self._io.read_u1()
            self.errors_error3_second = self._io.read_u1()
            self.errors_error3_error = self._io.read_u1()
            self.errors_error4_day = self._io.read_u1()
            self.errors_error4_hour = self._io.read_u1()
            self.errors_error4_minute = self._io.read_u1()
            self.errors_error4_second = self._io.read_u1()
            self.errors_error4_error = self._io.read_u1()
            self.errors_error5_day = self._io.read_u1()
            self.errors_error5_hour = self._io.read_u1()
            self.errors_error5_minute = self._io.read_u1()
            self.errors_error5_second = self._io.read_u1()
            self.errors_error5_error = self._io.read_u1()
            self.errors_error6_day = self._io.read_u1()
            self.errors_error6_hour = self._io.read_u1()
            self.errors_error6_minute = self._io.read_u1()
            self.errors_error6_second = self._io.read_u1()
            self.errors_error6_error = self._io.read_u1()
            self.errors_error7_day = self._io.read_u1()
            self.errors_error7_hour = self._io.read_u1()
            self.errors_error7_minute = self._io.read_u1()
            self.errors_error7_second = self._io.read_u1()
            self.errors_error7_error = self._io.read_u1()
            self.fc_salt = (self._io.read_bytes(4)).decode(u"utf-8")
            self.fc_crc = self._io.read_u1()
            self.frame_end = self._io.ensure_fixed_contents(b"\x5E")



